@@ -1,5 +1,4 @@
 import csv
-import hashlib
 import os
 import shutil
 import tempfile
@@ -7,16 +6,16 @@ import uuid
 import xml
 from datetime import datetime
 from xml.dom import minidom
+from xml.etree import ElementTree
 from xml.etree.ElementTree import Element, SubElement
 from xml.etree.ElementTree import ElementTree
-from xml.etree import ElementTree
 
 import boto3
 from boto3.s3.transfer import TransferConfig
 from botocore.config import Config
 from botocore.exceptions import ClientError
 
-from pyPreservica.common import AuthenticatedAPI, FileHash, Sha1FixityCallBack
+from pyPreservica.common import AuthenticatedAPI, Sha1FixityCallBack
 
 GB = 1024 ** 3
 transfer_config = TransferConfig(multipart_threshold=int((1 * GB) / 8))
@@ -25,7 +24,7 @@ transfer_config = TransferConfig(multipart_threshold=int((1 * GB) / 8))
 def prettify(elem):
     """Return a pretty-printed XML string for the Element.
     """
-    rough_string = ElementTree.tostring(elem, 'utf-8')
+    rough_string = xml.etree.ElementTree.tostring(elem, 'utf-8')
     re_parsed = minidom.parseString(rough_string)
     return re_parsed.toprettyxml(indent="  ")
 
@@ -375,8 +374,13 @@ def complex_asset_package(preservation_files_list=None, access_files_list=None,
         for content_ref, filename in preservation_refs_dict.items():
             default_content_objects_title = os.path.splitext(os.path.basename(filename))[0]
             preservation_content_title = kwargs.get('Preservation_Content_Title', default_content_objects_title)
-            preservation_content_description = kwargs.get('Preservation_Content_Description',
-                                                          default_content_objects_title)
+            preservation_content_description = kwargs.get('Preservation_Content_Description',  default_content_objects_title)
+
+            if isinstance(preservation_content_title, dict):
+                preservation_content_title = preservation_content_title[filename]
+
+            if isinstance(preservation_content_description, dict):
+                preservation_content_description = preservation_content_description[filename]
 
             __make_content_objects__(xip, preservation_content_title, content_ref, io_ref, security_tag,
                                      preservation_content_description, content_type)
@@ -385,9 +389,16 @@ def complex_asset_package(preservation_files_list=None, access_files_list=None,
 
         for content_ref, filename in access_refs_dict.items():
             default_content_objects_title = os.path.splitext(os.path.basename(filename))[0]
+
             access_content_title = kwargs.get('Access_Content_Title', default_content_objects_title)
             access_content_description = kwargs.get('Access_Content_Description', default_content_objects_title)
 
+            if isinstance(access_content_title, dict):
+                access_content_title = access_content_title[filename]
+
+            if isinstance(access_content_description, dict):
+                access_content_title = access_content_title[filename]
+
             __make_content_objects__(xip, access_content_title, content_ref, io_ref, security_tag,
                                      access_content_description, content_type)
 
@@ -448,7 +459,7 @@ def complex_asset_package(preservation_files_list=None, access_files_list=None,
             if metadata_ns:
                 if metadata_path:
                     if os.path.exists(metadata_path) and os.path.isfile(metadata_path):
-                        descriptive_metadata = ElementTree.parse(metadata_path)
+                        descriptive_metadata = xml.etree.ElementTree.parse(source=metadata_path)
                         metadata = SubElement(xip, 'Metadata', {'schemaUri': metadata_ns})
                         metadata_ref = SubElement(metadata, 'Ref')
                         metadata_ref.text = str(uuid.uuid4())
